/*
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <thrift/lib/cpp/protocol/TType.h>

namespace apache {
namespace thrift {
namespace detail {

template <typename Protocol>
struct ProtocolReaderWireTypeInfo {
  using WireType = apache::thrift::protocol::TType;
  static WireType fromTType(apache::thrift::protocol::TType ttype) {
    return ttype;
  }

  static WireType defaultValue() { return protocol::TType::T_STOP; }
};

} // namespace detail
} // namespace thrift
} // namespace apache
